import { type DescribeChangeSetOutput } from '@aws-cdk/cloudformation-diff';
import type * as cxapi from '@aws-cdk/cx-api';
import type { NestedStackTemplates } from '../api/cloudformation';
/**
 * Output of formatStackDiff
 */
export interface FormatStackDiffOutput {
    /**
     * Number of stacks with diff changes
     */
    readonly numStacksWithChanges: number;
    /**
     * Complete formatted diff
     */
    readonly formattedDiff: string;
}
/**
 * Formats the differences between two template states and returns it as a string.
 *
 * @param oldTemplate the old/current state of the stack.
 * @param newTemplate the new/target state of the stack.
 * @param strict      do not filter out AWS::CDK::Metadata or Rules
 * @param context     lines of context to use in arbitrary JSON diff
 * @param quiet       silences \'There were no differences\' messages
 *
 * @returns the formatted diff, and the number of stacks in this stack tree that have differences, including the top-level root stack
 */
export declare function formatStackDiff(oldTemplate: any, newTemplate: cxapi.CloudFormationStackArtifact, strict: boolean, context: number, quiet: boolean, stackName?: string, changeSet?: DescribeChangeSetOutput, isImport?: boolean, nestedStackTemplates?: {
    [nestedStackLogicalId: string]: NestedStackTemplates;
}): FormatStackDiffOutput;
export declare enum RequireApproval {
    Never = "never",
    AnyChange = "any-change",
    Broadening = "broadening"
}
/**
 * Output of formatSecurityDiff
 */
export interface FormatSecurityDiffOutput {
    /**
     * Complete formatted security diff, if it is prompt-worthy
     */
    readonly formattedDiff?: string;
}
/**
 * Formats the security changes of this diff, if the change is impactful enough according to the approval level
 *
 * Returns the diff if the changes are prompt-worthy, an empty object otherwise.
 */
export declare function formatSecurityDiff(oldTemplate: any, newTemplate: cxapi.CloudFormationStackArtifact, requireApproval: RequireApproval, stackName?: string, changeSet?: DescribeChangeSetOutput): FormatSecurityDiffOutput;
